Credits
=======

Development Lead
----------------

- TIA Centre led by Nasir Rajpoot <tia@dcs.warwick.ac.uk>
- Shan E Ahmed Raza  <shaneahmed>
- John Pocock <John-P>
- Simon Graham <simongraham>
- Dang Vu <vqdang>
- Mostafa Jahanifar <mostafajahanifar>
- David Epstein <DavidBAEpstein>
- Srijay Deshpande <Srijay-lab>
- George Hadjigeorgiou <ghadjigeorghiou>
- Adam Shephard <adamshephard>
- Wenqi Lu <wenqi006>
- Saad Bashir <rajasaad>

Contributors
------------

- Rob Jewsbury <R-J96>
- Mohsin Bilal <>
